
# Change Log
All notable changes to this project will be documented in this file.
 
The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).
 
## [Unreleased] - yyyy-mm-dd

## [0.2.10] - 2022-04-13

### Changed
- Cleanup
- Renamed model to module

## [0.2.7] - 2022-03-30

### Changed
- Changed job response structure and valdiation

## [0.2.5] - 2022-03-25

### Fixed
- Fixed missing argument for validate_data method in response base class

## [0.2.4] - 2022-03-23

### Added
- Added support for a module's job load weight data

## [0.2.3] - 2022-03-22

### Changed
- Project data

## [0.2.2] - 2022-03-22

### Added
- Data validation for response classes
- Static rules response class
